@@ -17,7 +17,7 @@ context(AppInfo) ->
     Mappings = [{".beam", EbinDir}],
 
     OutDir = rebar_app_info:dir(AppInfo),
-    SrcDirs = rebar_dir:src_dirs(rebar_app_info:opts(AppInfo), ["src"]),
+    SrcDirs = rebar_dir:src_dirs(rebar_app_info:opts(AppInfo)),
     ExistingSrcDirs = lists:filter(fun(D) ->
                                            ec_file:is_dir(filename:join(OutDir, D))
                                    end, SrcDirs),
@@ -31,7 +31,7 @@ context(AppInfo) ->
               %% all source directories are valid, and might also be recursive
               lists:append([
                   find_recursive_incl(OutDir, Src, RebarOpts) ||
-                  Src <- rebar_dir:all_src_dirs(RebarOpts, ["src"], [])
+                  Src <- rebar_dir:all_src_dirs(RebarOpts)
               ]) ++
               %% top-level dir for legacy stuff
               [OutDir],
@@ -84,7 +84,7 @@ needed_files(Graph, FoundFiles, _, AppInfo) ->
     ),
 
     PrivIncludes = [{i, filename:join(OutDir, Src)}
-                    || Src <- rebar_dir:all_src_dirs(RebarOpts, ["src"], [])],
+                    || Src <- rebar_dir:all_src_dirs(RebarOpts)],
     AdditionalOpts = PrivIncludes ++ [{i, filename:join(OutDir, "include")}, {i, OutDir}, return],
 
     true = digraph:delete(SubGraph),
@@ -138,7 +138,7 @@ compile(Source, [{_, OutDir}], Config, ErlOpts) ->
             ok;
         {ok, _Mod, Ws} ->
             FormattedWs = format_error_sources(Ws, Config),
-            rebar_compiler:ok_tuple(Source, FormattedWs);
+            rebar_compiler:ok_tuple(Source, FormattedWs, Config, ErlOpts);
         {error, Es, Ws} ->
             error_tuple(Source, Es, Ws, Config, ErlOpts);
         error ->
@@ -161,7 +161,7 @@ compile_and_track(Source, [{Ext, OutDir}], Config, ErlOpts) ->
             {ok, [{Source, Target, AllOpts}]};
         {ok, _Mod, Ws} ->
             FormattedWs = format_error_sources(Ws, Config),
-            {ok, Warns} = rebar_compiler:ok_tuple(Source, FormattedWs),
+            {ok, Warns} = rebar_compiler:ok_tuple(Source, FormattedWs, Config, ErlOpts),
             {ok, [{Source, Target, AllOpts}], Warns};
         {error, Es, Ws} ->
             error_tuple(Source, Es, Ws, Config, ErlOpts);
@@ -183,7 +183,7 @@ clean(Files, AppInfo) ->
 error_tuple(Module, Es, Ws, AllOpts, Opts) ->
     FormattedEs = format_error_sources(Es, AllOpts),
     FormattedWs = format_error_sources(Ws, AllOpts),
-    rebar_compiler:error_tuple(Module, FormattedEs, FormattedWs, Opts).
+    rebar_compiler:error_tuple(Module, FormattedEs, FormattedWs, AllOpts, Opts).
 
 format_error_sources(Es, Opts) ->
     [{rebar_compiler:format_error_source(Src, Opts), Desc}
@@ -241,7 +241,7 @@ filename_to_atom(F) -> list_to_atom(filename:rootname(filename:basename(F))).
 %% dependencies induced by given graph G.
 needed_files(Graph, ErlOpts, RebarOpts, Dir, OutDir, SourceFiles) ->
     PrivIncludes = [{i, filename:join(Dir, Src)}
-                    || Src <- rebar_dir:all_src_dirs(RebarOpts, ["src"], [])],
+                    || Src <- rebar_dir:all_src_dirs(RebarOpts)],
     SharedOpts = [{i, filename:join(Dir, "include")},
                   {i, Dir}] ++ PrivIncludes ++ ErlOpts,
     CompilerOptsSet = erl_compiler_opts_set(),
@@ -454,11 +454,11 @@ maybe_expand_include_lib_path(File, Dir) ->
         [_] ->
             warn_and_find_path(File, Dir);
         [Lib | SubDir] ->
-            case code:lib_dir(list_to_atom(Lib), list_to_atom(filename:join(SubDir))) of
+            case code:lib_dir(list_to_atom(Lib)) of
                 {error, bad_name} ->
                     warn_and_find_path(File, Dir);
                 AppDir ->
-                    [filename:join(AppDir, File1)]
+                    [filename:join([AppDir] ++ SubDir ++ [File1])]
             end
     end.
 
